@@ -6,7 +6,7 @@
  *	@author		Masaki Fujimoto <fujimoto@php.net>
  *	@license	http://www.opensource.org/licenses/bsd-license.php The BSD License
  *	@package	Ethna
- *	@version	$Id: Ethna_ActionClass.php,v 1.2 2004/12/13 15:08:38 fujimoto Exp $
+ *	@version	$Id: Ethna_ActionClass.php,v 1.7 2006/06/05 15:00:18 fujimoto Exp $
  */
 
 // {{{ Ethna_ActionClass
@@ -23,44 +23,28 @@ class Ethna_ActionClass
 	 *	@access	private
 	 */
 
-	/**
-	 *	@var	object	Ethna_Backend		backend֥
-	 */
+	/**	@var	object	Ethna_Backend		backend֥ */
 	var $backend;
 
-	/**
-	 *	@var	object	Ethna_Config		ꥪ֥	
-	 */
+	/**	@var	object	Ethna_Config		ꥪ֥	*/
 	var $config;
 
-	/**
-	 *	@var	object	Ethna_I18N			i18n֥
-	 */
+	/**	@var	object	Ethna_I18N			i18n֥ */
 	var $i18n;
 
-	/**
-	 *	@var	object	Ethna_ActionError	󥨥顼֥
-	 */
+	/**	@var	object	Ethna_ActionError	󥨥顼֥ */
 	var $action_error;
 
-	/**
-	 *	@var	object	Ethna_ActionError	󥨥顼֥(ά)
-	 */
+	/**	@var	object	Ethna_ActionError	󥨥顼֥(ά) */
 	var $ae;
 
-	/**
-	 *	@var	object	Ethna_ActionForm	ե४֥
-	 */
+	/**	@var	object	Ethna_ActionForm	ե४֥ */
 	var $action_form;
 
-	/**
-	 *	@var	object	Ethna_ActionForm	ե४֥(ά)
-	 */
+	/**	@var	object	Ethna_ActionForm	ե४֥(ά) */
 	var $af;
 
-	/**
-	 *	@var	object	Ethna_Session		å󥪥֥
-	 */
+	/**	@var	object	Ethna_Session		å󥪥֥ */
 	var $session;
 
 	/**#@-*/
@@ -89,15 +73,26 @@ class Ethna_ActionClass
 		// Ethna_AppManager֥Ȥ
 		$manager_list = $c->getManagerList();
 		foreach ($manager_list as $k => $v) {
-			$this->$k = $backend->getManager($v);
+			$this->$k =& $backend->getManager($v);
 		}
 	}
 
 	/**
-	 *	ӥͥå¹ν(ååեͥå)Ԥ
+	 *	¹ǧڽԤ
 	 *
 	 *	@access	public
-	 *	@return	string	Forward̾(nullʤｪλ)
+	 *	@return	string	̾(nullʤｪλ, falseʤλ)
+	 */
+	function authenticate()
+	{
+		return null;
+	}
+
+	/**
+	 *	¹ν(եͥå)Ԥ
+	 *
+	 *	@access	public
+	 *	@return	string	̾(nullʤｪλ, falseʤλ)
 	 */
 	function prepare()
 	{
@@ -105,24 +100,15 @@ class Ethna_ActionClass
 	}
 
 	/**
-	 *	action
+	 *	¹
 	 *
 	 *	@access	public
-	 *	@return	string	Forward̾
+	 *	@return	string	̾(nullʤܤϹԤʤ)
 	 */
 	function perform()
 	{
 		return null;
 	}
-
-	/**
-	 *	ɽ
-	 *
-	 *	@access	public
-	 */
-	function preforward()
-	{
-	}
 }
 // }}}
 ?>
