@@ -6,7 +6,7 @@
  *  @author     Masaki Fujimoto <fujimoto@php.net>
  *  @license    http://www.opensource.org/licenses/bsd-license.php The BSD License
  *  @package    Ethna
- *  @version    $Id: Ethna_Controller.php,v 1.51 2006/06/05 15:58:49 fujimoto Exp $
+ *  @version    $Id: Ethna_Controller.php,v 1.51.2.1 2006/06/07 06:13:44 fujimoto Exp $
  */
 
 // {{{ Ethna_Controller
@@ -1030,9 +1030,9 @@ class Ethna_Controller
     {
         $s = null; 
         if ($type == "hidden") {
-            $s = sprintf('<input type="hidden" name="%s" value="true">', htmlspecialchars($action, ENT_QUOTES));
+            $s = sprintf('<input type="hidden" name="action_%s" value="true">', htmlspecialchars($action, ENT_QUOTES));
         } else if ($type == "url") {
-            $s = sprintf('%s=true', urlencode($action));
+            $s = sprintf('action_%s=true', urlencode($action));
         }
         return $s;
     }
