@@ -6,7 +6,7 @@
  *	@author		Masaki Fujimoto <fujimoto@php.net>
  *	@license	http://www.opensource.org/licenses/bsd-license.php The BSD License
  *	@package	Ethna
- *	@version	$Id: Ethna_Logger.php,v 1.4 2005/01/06 17:44:23 fujimoto Exp $
+ *	@version	$Id: Ethna_Logger.php,v 1.10 2006/03/25 10:40:19 fujimoto Exp $
  */
 
 /**
@@ -14,10 +14,20 @@
  */
 define('LOG_FILE', 1 << 16);
 
+/**
+ *	ĥץѥƥ:	ɸ
+ */
+define('LOG_ECHO', 1 << 17);
+
 /**
  *	ĥץѥƥ:	ؿ̾ɽ
  */
-define('LOG_FUNCTION', 1 << 17);
+define('LOG_FUNCTION', 1 << 18);
+
+/**
+ *	ĥץѥƥ:	ե̾+ֹɽ
+ */
+define('LOG_POS', 1 << 19);
 
 
 // {{{ ethna_error_handler
@@ -31,16 +41,53 @@ define('LOG_FUNCTION', 1 << 17);
  */
 function ethna_error_handler($errno, $errstr, $errfile, $errline)
 {
-	$c =& Ethna_Controller::getInstance();
-
-	list($level, $name) = Ethna_Logger::errorLevelToLogLevel($errno);
 	if ($errno == E_STRICT) {
 		// E_STRICTɽʤ
 		return E_STRICT;
 	}
 
+	list($level, $name) = Ethna_Logger::errorLevelToLogLevel($errno);
+	switch ($errno) {
+	case E_ERROR:
+	case E_CORE_ERROR:
+	case E_COMPILE_ERROR:
+	case E_USER_ERROR:
+		$php_errno = 'Fatal error'; break;
+	case E_WARNING:
+	case E_CORE_WARNING:
+	case E_COMPILE_WARNING:
+	case E_USER_WARNING:
+		$php_errno = 'Warning'; break;
+	case E_PARSE:
+		$php_errno = 'Parse error'; break;
+	case E_NOTICE:
+	case E_USER_NOTICE:
+		$php_errno = 'Notice'; break;
+	default:
+		$php_errno = 'Unknown error'; break;
+	}
+
+	$php_errstr = sprintf('PHP %s: %s in %s on line %d', $php_errno, $errstr, $errfile, $errline);
+	if (ini_get('log_errors') && (error_reporting() & $errno)) {
+		$locale = setlocale(LC_TIME, 0);
+		setlocale(LC_TIME, 'C');
+		error_log($php_errstr, 0);
+		setlocale(LC_TIME, $locale);
+	}
+
+	$c =& Ethna_Controller::getInstance();
 	$logger =& $c->getLogger();
-	$logger->log($level, sprintf("[PHP] %s: %s in %s on line %d", $code, $errstr, $errfile, $errline));
+	$logger->log($level, sprintf("[PHP] %s: %s in %s on line %d", $name, $errstr, $errfile, $errline));
+
+	$facility = $logger->getLogFacility();
+	if (($facility != LOG_ECHO) && ini_get('display_errors') && (error_reporting() & $errno)) {
+		if ($c->getCLI()) {
+			$format = "%s: %s in %s on line %d\n";
+		} else {
+			$format = "<b>%s</b>: %s in <b>%s</b> on line <b>%d</b><br />\n";
+		}
+		printf($format, $php_errno, $errstr, $errfile, $errline);
+	}
 }
 // }}}
 
@@ -65,14 +112,6 @@ class Ethna_Logger extends Ethna_AppManager
 		'cron' => array('name' => 'LOG_CRON'),
 		'daemon' => array('name' => 'LOG_DAEMON'),
 		'kern' => array('name' => 'LOG_KERN'),
-		'local0' => array('name' => 'LOG_LOCAL0'),
-		'local1' => array('name' => 'LOG_LOCAL1'),
-		'local2' => array('name' => 'LOG_LOCAL2'),
-		'local3' => array('name' => 'LOG_LOCAL3'),
-		'local4' => array('name' => 'LOG_LOCAL4'),
-		'local5' => array('name' => 'LOG_LOCAL5'),
-		'local6' => array('name' => 'LOG_LOCAL6'),
-		'local7' => array('name' => 'LOG_LOCAL7'),
 		'lpr' => array('name' => 'LOG_LPR'),
 		'mail' => array('name' => 'LOG_MAIL'),
 		'news' => array('name' => 'LOG_NEWS'),
@@ -80,6 +119,7 @@ class Ethna_Logger extends Ethna_AppManager
 		'user' => array('name' => 'LOG_USER'),
 		'uucp' => array('name' => 'LOG_UUCP'),
 		'file' => array('name' => 'LOG_FILE'),
+		'echo' => array('name' => 'LOG_ECHO'),
 	);
 
 	/**	@var	array	٥ */
@@ -98,6 +138,7 @@ class Ethna_Logger extends Ethna_AppManager
 	var $log_option_list = array(
 		'pid' => array('name' => 'PIDɽ', 'value' => LOG_PID),
 		'function' => array('name' => 'ؿ̾ɽ', 'value' => LOG_FUNCTION),
+		'pos' => array('name' => 'ե̾ɽ', 'value' => LOG_POS),
 	);
 
 	/**	@var	array	٥ơ֥ */
@@ -118,6 +159,9 @@ class Ethna_Logger extends Ethna_AppManager
 	/**	@var	int		٥ */
 	var $level;
 
+	/**	@var	int		եƥ */
+	var $facility;
+
 	/**	@var	int		顼ȥ٥ */
 	var $alert_level;
 
@@ -152,26 +196,37 @@ class Ethna_Logger extends Ethna_AppManager
 			// ̤ʤLOG_WARNING
 			$this->level = LOG_WARNING;
 		}
-		$facility = $this->_parseLogFacility($config->get('log_facility'));
-		$file = sprintf('%s/%s.log', $controller->getDirectory('log'), strtolower($controller->getAppid()));
+		$this->facility = $this->_parseLogFacility($config->get('log_facility'));
 		$option = $this->_parseLogOption($config->get('log_option'));
 		$this->alert_level = $this->_parseLogLevel($config->get('log_alert_level'));
 		$this->alert_mailaddress = preg_split('/\s*,\s*/', $config->get('log_alert_mailaddress'));
 		$this->message_filter_do = $config->get('log_filter_do');
 		$this->message_filter_ignore = $config->get('log_filter_ignore');
 
-		if ($facility == LOG_FILE) {
-			$writer_class = "Ethna_LogWriter_File";
-		} else if (is_null($facility)) {
-			$writer_class = "Ethna_LogWriter";
-		} else {
-			$writer_class = "Ethna_LogWriter_Syslog";
+		// LogWriter饹
+		$file = $this->_getLogFile();
+		$this->writer =& $this->_getLogWriter($file, $option);
+
+		for ($i = 0; $i < 8; $i++) {
+			if (defined("LOG_LOCAL$i")) {
+				$this->log_facility_list["local$i"] = array('name' => "LOG_LOCAL$i");
+			}
 		}
-		$this->writer =& new $writer_class($controller->getAppId(), $facility, $file, $option);
 
 		set_error_handler("ethna_error_handler");
 	}
 
+	/**
+	 *	եƥ
+	 *
+	 *	@access	public
+	 *	@return	int		եƥ
+	 */
+	function getLogFacility()
+	{
+		return $this->facility;
+	}
+
 	/**
 	 *	PHP顼٥٥Ѵ
 	 *
@@ -252,6 +307,63 @@ class Ethna_Logger extends Ethna_AppManager
 		$this->writer->end();
 	}
 
+	/**
+	 *	եν񤭽Ф(եƥ
+	 *	LOG_FILEꤵƤΤͭ)
+	 *
+	 *	եν񤭽ФѹϤΥ᥽åɤ
+	 *	С饤ɤޤ
+	 *
+	 *	@access	protected
+	 *	@return	string	եν񤭽Ф
+	 */
+	function _getLogFile()
+	{
+		return sprintf('%s/%s.log',
+			$this->controller->getDirectory('log'),
+			strtolower($this->controller->getAppid())
+		);
+	}
+
+	/**
+	 *	LogWriter֥Ȥ
+	 *
+	 *	ץꥱͭLogWriterѤϤΥ᥽åɤ
+	 *	С饤ɤޤ
+	 *
+	 *	@access	protected
+	 *	@param	string	$file		ե
+	 *	@param	array	$option		ץ
+	 *	@return	object	LogWriter	LogWriter֥
+	 */
+	function &_getLogWriter($file, $option)
+	{
+		if (is_null($this->facility)) {
+			$writer_class = "Ethna_LogWriter";
+		} else if (is_integer($this->facility)) {
+			if ($this->facility == LOG_FILE) {
+				$writer_class = "Ethna_LogWriter_File";
+			} else if ($this->facility == LOG_ECHO) {
+                if ($this->controller->getGateway() == GATEWAY_WWW ||
+                    $this->controller->getGateway() == GATEWAY_CLI) {
+                    $writer_class = "Ethna_LogWriter_Echo";
+                } else {
+                    $writer_class = "Ethna_LogWriter";
+                }
+			} else {
+				$writer_class = "Ethna_LogWriter_Syslog";
+			}
+		} else if (is_string($this->facility)) {
+			$writer_class = $this->facility;
+			if (class_exists($writer_class) == false) {
+				// falling back to default
+				$writer_class = "Ethna_LogWriter";
+			}
+		}
+		$_ret_object = new $writer_class($this->controller->getAppId(), $this->facility, $file, $option);
+		return $_ret_object;
+	}
+
 	/**
 	 *	ץ(ե)Ϥ
 	 *
@@ -268,6 +380,8 @@ class Ethna_Logger extends Ethna_AppManager
 				$option |= LOG_PID;
 			} else if ($elt == 'function') {
 				$option |= LOG_FUNCTION;
+			} else if ($elt == 'pos') {
+				$option |= LOG_POS;
 			}
 		}
 
@@ -299,7 +413,7 @@ class Ethna_Logger extends Ethna_AppManager
 		}
 
 		foreach ($this->alert_mailaddress as $mailaddress) {
-			mail($mailaddress, $subject, mb_convert_encoding($mail, "ISO-2022-JP", "EUC-JP"), $header);
+			mail($mailaddress, $subject, mb_convert_encoding($mail, "ISO-2022-JP"), $header);
 		}
 
 		set_error_handler("ethna_error_handler");
@@ -365,14 +479,6 @@ class Ethna_Logger extends Ethna_AppManager
 			'cron'		=> LOG_CRON,
 			'daemon'	=> LOG_DAEMON,
 			'kern'		=> LOG_KERN,
-			'local0'	=> LOG_LOCAL0,
-			'local1'	=> LOG_LOCAL1,
-			'local2'	=> LOG_LOCAL2,
-			'local3'	=> LOG_LOCAL3,
-			'local4'	=> LOG_LOCAL4,
-			'local5'	=> LOG_LOCAL5,
-			'local6'	=> LOG_LOCAL6,
-			'local7'	=> LOG_LOCAL7,
 			'lpr'		=> LOG_LPR,
 			'mail'		=> LOG_MAIL,
 			'news'		=> LOG_NEWS,
@@ -380,9 +486,17 @@ class Ethna_Logger extends Ethna_AppManager
 			'user'		=> LOG_USER,
 			'uucp'		=> LOG_UUCP,
 			'file'		=> LOG_FILE,
+			'echo'		=> LOG_ECHO,
 		);
+
+		for ($i = 0; $i < 8; $i++) {
+			if (defined("LOG_LOCAL$i")) {
+				$facility_map_table["local$i"] = constant("LOG_LOCAL$i");
+			}
+		}
+
 		if (isset($facility_map_table[strtolower($facility)]) == false) {
-			return null;
+			return $facility;
 		}
 		return $facility_map_table[strtolower($facility)];
 	}
