@@ -5,7 +5,7 @@
  *	@author		Masaki Fujimoto <fujimoto@php.net>
  *	@license	http://www.opensource.org/licenses/bsd-license.php The BSD License
  *	@package	Ethna
- *	@version	$Id: Ethna_SmartyPlugin.php,v 1.4 2004/12/27 17:43:05 fujimoto Exp $
+ *	@version	$Id: Ethna_SmartyPlugin.php,v 1.14 2006/05/09 03:14:29 fujimoto Exp $
  */
 
 /**
@@ -194,7 +194,9 @@ function smarty_modifier_unique($array, $key = null)
 }
 
 /**
- *	smarty modifier:ʸwordwrap(EUC-JPб)
+ *	smarty modifier:ʸwordwrap
+ *
+ *	[EUC-JPбEUC-JPΤб]
  *
  *	sample:
  *	<code>
@@ -219,6 +221,14 @@ function smarty_modifier_wordwrap_i18n($string, $width, $break = "\n", $indent =
 	$i = "$break" . str_repeat(" ", $indent);
 	$tmp = $string;
 	do {
+		$n = strpos($tmp, $break);
+		if ($n !== false && $n < $width) {
+			$s = substr($tmp, 0, $n);
+			$r .= $s . $i;
+			$tmp = substr($tmp, strlen($s) + strlen($break));
+			continue;
+		}
+
 		$s = mb_strimwidth($tmp, 0, $width, "", "EUC-JP");
 
 		// EUC-JPΤб
@@ -242,6 +252,25 @@ function smarty_modifier_wordwrap_i18n($string, $width, $break = "\n", $indent =
 	return $r;
 }
 
+/**
+ *	smarty modifier:ʸڤͤ(i18nб)
+ *
+ *	sample:
+ *	<code>
+ *	{"ܸǤ"|truncate_i18n:5:"..."}
+ *	</code>
+ *	<code>
+ *	...
+ *	</code>
+ *
+ *	@param	int		$len		ʸ
+ *	@param	string	$postfix	ղäʸ
+ */
+function smarty_modifier_truncate_i18n($string, $len = 80, $postfix = "...")
+{
+	return mb_strimwidth($string, 0, $len, $postfix);
+}
+
 /**
  *	smarty modifier:i18nե륿
  *
@@ -313,7 +342,7 @@ function smarty_modifier_checkbox($string)
 function smarty_modifier_select($string, $value)
 {
 	if ($string == $value) {
-		print "selected";
+		print 'selected="true"';
 	}
 }
 
@@ -346,7 +375,7 @@ function smarty_modifier_form_value($string)
 		$r = $r[$elts[$i]];
 	}
 
-	return htmlspecialchars($r);
+	return htmlspecialchars($r, ENT_QUOTES);
 }
 
 /**
@@ -428,14 +457,18 @@ function smarty_function_uniqid($params, &$smarty)
  *	@param	array	$list	
  *	@param	string	$name	ե̾
  *	@param	string	$value	쥯ȥܥåϤ줿ե
+ *	@param	string	$empty	ȥ(---򤷤Ʋ---)
  */
 function smarty_function_select($params, &$smarty)
 {
 	extract($params);
 
 	print "<select name=\"$name\">\n";
+	if ($empty) {
+		printf("<option value=\"\">%s</option>\n", $empty);
+	}
 	foreach ($list as $id => $elt) {
-		printf("<option value=\"%s\" %s>%s</option>\n", $id, $id == $value ? "selected" : "", $elt['name']);
+		printf("<option value=\"%s\" %s>%s</option>\n", $id, $id == $value ? 'selected="true"' : '', $elt['name']);
 	}
 	print "</select>\n";
 }
@@ -483,4 +516,102 @@ function smarty_function_checkbox_list($params, &$smarty)
 		}
 	}
 }
+
+/**
+ *	smarty function:եɽ̾
+ *
+ *	@param	string	$name	ե̾
+ */
+function smarty_function_form_name($params, &$smarty)
+{
+    if (isset($params['name']) == false) {
+        return null;
+    }
+    $name = $params['name'];
+    unset($params['name']);
+
+	$c =& Ethna_Controller::getInstance();
+    $view =& $c->getView();
+    if ($view === null) {
+        return null;
+    }
+    print $view->getFormName($name, $params);
+}
+
+/**
+ *	smarty function:եॿ
+ *
+ *	@param	string	$name	ե̾
+ */
+function smarty_function_form_input($params, &$smarty)
+{
+    if (isset($params['name']) == false) {
+        return null;
+    }
+    $name = $params['name'];
+    unset($params['name']);
+
+	$c =& Ethna_Controller::getInstance();
+    $view =& $c->getView();
+    if ($view === null) {
+        return null;
+    }
+    print $view->getFormInput($name, $params);
+}
+
+/**
+ *	smarty block:եॿϥץ饰
+ */
+function smarty_block_form($params, $content, &$smarty, &$repeat)
+{
+	extract($params);
+
+    $s = "";
+    if ($repeat) {
+        $s = "<form";
+
+        // fundamentals
+        if ($action !== false) {
+            if (isset($action) == false) {
+                $action = basename($_SERVER['PHP_SELF']);
+            }
+            $s .= sprintf(' action="%s"', htmlspecialchars($action, ENT_QUOTES));
+        }
+        if ($method !== false) {
+            if (isset($method) == false) {
+                $method = "post";
+            }
+            $s .= sprintf(' method="%s"', htmlspecialchars($method, ENT_QUOTES));
+        }
+
+        // enctypedefault off(-> "!=")
+        // + ͤɤΤάб("file"Ȥ...?)
+        if ($enctype != "") {
+            if ($enctype == "file" || $enctype == "multipart") {
+                $enctype = "multipart/form-data";
+            } else if ($enctype == "url") {
+                $enctype = "application/x-www-form-urlencoded";
+            }
+            $s .= sprintf(' enctype="%s"', htmlspecialchars($enctype, ENT_QUOTES));
+        }
+
+        // additionals
+        foreach (array('accept', 'accept-charset', 'autocomplete', 'class', 'id', 'lang', 'name', 'style', 'target', 'title', 'urn') as $key) {
+            if (${$key} != "") {
+                $s .= sprintf(' %s="%s"', $key, htmlspecialchars(${$key}, ENT_QUOTES));
+            }
+        }
+
+        $s .= ">";
+
+        if ($ethna_action != "") {
+            $c =& Ethna_Controller::getInstance();
+            $s .= $c->getActionRequest($ethna_action, "hidden");
+        }
+    } else {
+        print $content;
+        $s = "</form>";
+    }
+    print $s;
+}
 ?>
