@@ -2,15 +2,15 @@
 /**
  *	Index.php
  *
+ *	@author		{$author}
  *	@package	{$project_id}
- *
- *	$Id: app.action.default.php,v 1.8 2004/12/06 17:25:11 fujimoto Exp $
+ *	@version 	$Id: app.action.default.php,v 1.12 2006/03/23 13:16:37 fujimoto Exp $
  */
 
 /**
  *	indexեμ
  *
- *	@author		yourname
+ *	@author		{$author}
  *	@access		public
  *	@package	{$project_id}
  */
@@ -34,7 +34,7 @@ class {$project_id}_Form_Index extends Ethna_ActionForm
 		 *		'regexp'        => null,			// ʸ(ɽ)
 		 *		'custom'        => null,			// ᥽åɤˤå
 		 *		'filter'        => null,			// Ѵե륿ץ
-		 *		'form_type'		=> FORM_TYPE_TEXT	// ե෿
+		 *		'form_type'     => FORM_TYPE_TEXT,	// ե෿
 		 *		'type'          => VAR_TYPE_INT,	// ͷ
 		 *	),
 		 */
@@ -44,7 +44,7 @@ class {$project_id}_Form_Index extends Ethna_ActionForm
 /**
  *	indexμ
  *
- *	@author		yourname
+ *	@author		{$author}
  *	@access		public
  *	@package	{$project_id}
  */
