@@ -2,15 +2,15 @@
 /**
  *	{$project_id}_Filter_ExecutionTime.php
  *
- *	@author		your name
+ *	@author		{$author}
  *	@package	{$project_id}
- *	@version	$Id: app.filter.default.php,v 1.2 2004/12/14 07:23:12 fujimoto Exp $
+ *	@version	$Id: app.filter.default.php,v 1.5 2006/06/05 15:54:32 fujimoto Exp $
  */
 
 /**
  *	¹Իַ¬ե륿μ
  *
- *	@author		your name
+ *	@author		{$author}
  *	@access		public
  *	@package	{$project_id}
  */
@@ -33,19 +33,44 @@ class {$project_id}_Filter_ExecutionTime extends Ethna_Filter
 	 *
 	 *	@access	public
 	 */
-	function prefilter()
+	function preFilter()
 	{
 		$stime = explode(' ', microtime());
 		$stime = $stime[1] + $stime[0];
 		$this->stime = $stime;
 	}
 
+	/**
+	 *	¹ե륿
+	 *
+	 *	@access	public
+	 *	@param	string	$action_name	¹Ԥ륢̾
+	 *	@return	string	null:ｪλ (string):¹Ԥ륢̾ѹ
+	 */
+	function preActionFilter($action_name)
+	{
+		return null;
+	}
+
+	/**
+	 *	¹Ըե륿
+	 *
+	 *	@access	public
+	 *	@param	string	$action_name	¹Ԥ줿̾
+	 *	@param	string	$forward_name	¹Ԥ줿󤫤
+	 *	@return	string	null:ｪλ (string):̾ѹ
+	 */
+	function postActionFilter($action_name, $forward_name)
+	{
+		return null;
+	}
+
 	/**
 	 *	¹Ըե륿
 	 *
 	 *	@access	public
 	 */
-	function postfilter()
+	function postFilter()
 	{
 		$etime = explode(' ', microtime());
 		$etime = $etime[1] + $etime[0];
